@@ -65,20 +65,14 @@ using std::string;
 using std::vector;
 using std::pair;
 using std::make_pair;
-#ifdef HAVE_UNORDERED_MAP
 using HASH_NAMESPACE::unordered_map;
-// This is totally cheap, but minimizes the need for #ifdef's below...
-#define hash_map unordered_map
-#else
-using HASH_NAMESPACE::hash_map;
-#endif
 
 static int kVerbosity = 0;   // you can change this by hand to get vlogs
 #define LOG(level)   std::cerr << #level ": "
 #define PLOG(level)   std::cerr << #level ": [" << strerror(errno) << "] "
 #define VLOG(level)  if (kVerbosity >= level)  std::cerr << "V" #level ": "
 
-_START_GOOGLE_NAMESPACE_
+namespace ctemplate {
 
 // ----------------------------------------------------------------------
 // TemplateCache::RefcountedTemplate
@@ -419,18 +413,17 @@ bool TemplateCache::ExpandNoLoad(
     ExpandEmitter *expand_emitter) const {
   TemplateCacheKey template_cache_key(filename.GetGlobalId(), strip);
   CachedTemplate cached_tpl;
-  TemplateMap::iterator it;
   {
     ReaderMutexLock ml(mutex_);
     if (!is_frozen_) {
       LOG(DFATAL) << ": ExpandNoLoad() only works on frozen caches.";
       return false;
     }
-    it = parsed_template_cache_->find(template_cache_key);
-    if (it == parsed_template_cache_->end()) {
+    CachedTemplate* it = find_ptr(*parsed_template_cache_, template_cache_key);
+    if (!it) {
       return false;
     }
-    cached_tpl = it->second;
+    cached_tpl = *it;
     cached_tpl.refcounted_tpl->IncRef();
   }
   const bool result = cached_tpl.refcounted_tpl->tpl()->ExpandWithDataAndCache(
@@ -732,13 +725,8 @@ TemplateCache* TemplateCache::Clone() const {
 
 int TemplateCache::Refcount(const TemplateCacheKey template_cache_key) const {
   ReaderMutexLock ml(mutex_);
-  TemplateMap::const_iterator it =
-      parsed_template_cache_->find(template_cache_key);
-  if (it != parsed_template_cache_->end()) {
-    return it->second.refcounted_tpl->refcount();
-  } else {
-    return 0;
-  }
+  CachedTemplate* it = find_ptr(*parsed_template_cache_, template_cache_key);
+  return it ? it->refcounted_tpl->refcount() : 0;
 }
 
 // ----------------------------------------------------------------------
@@ -750,8 +738,7 @@ int TemplateCache::Refcount(const TemplateCacheKey template_cache_key) const {
 bool TemplateCache::TemplateIsCached(const TemplateCacheKey template_cache_key)
     const {
   ReaderMutexLock ml(mutex_);
-  return (parsed_template_cache_->find(template_cache_key) !=
-          parsed_template_cache_->end());
+  return parsed_template_cache_->count(template_cache_key);
 }
 
 // ----------------------------------------------------------------------
@@ -776,4 +763,4 @@ bool TemplateCache::IsValidTemplateFilename(const string& filename,
   return true;
 }
 
-_END_GOOGLE_NAMESPACE_
+}
