@@ -86,9 +86,9 @@ using std::map;
 using std::pair;
 using std::string;
 using std::vector;
-using GOOGLE_NAMESPACE::PathJoin;
+using ctemplate::PathJoin;
 
-namespace HTMLPARSER_NAMESPACE {
+namespace ctemplate_htmlparser {
 
 // Maximum file size limit.
 static const int kMaxFileSize = 1000000;
